Package: apexcharter
Version: 0.4.5
Title: Create Interactive Chart with the JavaScript 'ApexCharts'
        Library
Description: Provides an 'htmlwidgets' interface to 'apexcharts.js'. 
  'Apexcharts' is a modern JavaScript charting library to build interactive charts and visualizations with simple API.
  'Apexcharts' examples and documentation are available here: <https://apexcharts.com/>.
Authors@R: c(
  person("Victor", "Perrier", email = "victor.perrier@dreamrs.fr", role = c("aut", "cre")),
  person("Fanny", "Meyer", role = "aut"),
  person("Juned", "Chhipa", role = "cph", comment = "apexcharts.js library"),
  person("Mike", "Bostock", role = "cph", comment = "d3.format library"))
License: MIT + file LICENSE
Encoding: UTF-8
LazyData: true
ByteCompile: true
Depends: R (>= 2.10)
Imports: htmltools, htmlwidgets (>= 1.5.3), magrittr, rlang, ggplot2,
        jsonlite, shiny (>= 1.1.0)
Suggests: testthat, knitr, scales, rmarkdown, covr
RoxygenNote: 7.3.3
URL: https://github.com/dreamRs/apexcharter,
        https://dreamrs.github.io/apexcharter/
BugReports: https://github.com/dreamRs/apexcharter/issues
VignetteBuilder: knitr
NeedsCompilation: no
Packaged: 2026-01-07 11:01:19 UTC; perri
Author: Victor Perrier [aut, cre],
  Fanny Meyer [aut],
  Juned Chhipa [cph] (apexcharts.js library),
  Mike Bostock [cph] (d3.format library)
Maintainer: Victor Perrier <victor.perrier@dreamrs.fr>
Repository: CRAN
Date/Publication: 2026-01-07 21:10:10 UTC
Built: R 4.6.0; ; 2026-04-28 23:11:55 UTC; unix
