# Generated by roxygen2: do not edit by hand

S3method(print,apex_facet)
S3method(print,apex_grid)
export("%>%")
export(JS)
export(add_event)
export(add_event_marker)
export(add_hline)
export(add_line)
export(add_point)
export(add_shade)
export(add_shade_weekend)
export(add_smooth_line)
export(add_vline)
export(aes)
export(apex)
export(apex_grid)
export(apexchart)
export(apexchartOutput)
export(apexchartProxy)
export(apexfacetOutput)
export(apexgridOutput)
export(ax_annotations)
export(ax_chart)
export(ax_colors)
export(ax_colors_manual)
export(ax_dataLabels)
export(ax_facet_grid)
export(ax_facet_wrap)
export(ax_fill)
export(ax_forecast_data_points)
export(ax_grid)
export(ax_labels)
export(ax_labels2)
export(ax_labs)
export(ax_legend)
export(ax_markers)
export(ax_nodata)
export(ax_plotOptions)
export(ax_proxy_options)
export(ax_proxy_series)
export(ax_responsive)
export(ax_series)
export(ax_series2)
export(ax_states)
export(ax_stroke)
export(ax_subtitle)
export(ax_theme)
export(ax_title)
export(ax_tooltip)
export(ax_xaxis)
export(ax_yaxis)
export(ax_yaxis2)
export(bar_opts)
export(boxplot_opts)
export(bubble_opts)
export(config_update)
export(events_opts)
export(format_date)
export(format_num)
export(heatmap_opts)
export(label)
export(label_value)
export(parse_df)
export(pie_opts)
export(radialBar_opts)
export(renderApexchart)
export(renderApexfacet)
export(renderApexgrid)
export(renderSparkBox)
export(run_demo_input)
export(run_demo_sparkbox)
export(run_demo_sync)
export(set_input_click)
export(set_input_export)
export(set_input_selection)
export(set_input_zoom)
export(set_tooltip_fixed)
export(sparkBoxOutput)
export(spark_box)
export(vars)
importFrom(ggplot2,aes)
importFrom(ggplot2,label_value)
importFrom(ggplot2,vars)
importFrom(graphics,boxplot)
importFrom(htmltools,css)
importFrom(htmltools,renderTags)
importFrom(htmltools,resolveDependencies)
importFrom(htmltools,tagList)
importFrom(htmltools,tags)
importFrom(htmltools,validateCssUnit)
importFrom(htmlwidgets,JS)
importFrom(htmlwidgets,JSEvals)
importFrom(htmlwidgets,createWidget)
importFrom(htmlwidgets,getDependency)
importFrom(htmlwidgets,shinyRenderWidget)
importFrom(htmlwidgets,shinyWidgetOutput)
importFrom(htmlwidgets,sizingPolicy)
importFrom(jsonlite,fromJSON)
importFrom(magrittr,"%>%")
importFrom(rlang,"!!")
importFrom(rlang,"%||%")
importFrom(rlang,as_label)
importFrom(rlang,eval_tidy)
importFrom(rlang,is_function)
importFrom(rlang,is_list)
importFrom(rlang,is_named)
importFrom(rlang,is_null)
importFrom(rlang,quo)
importFrom(rlang,quos)
importFrom(rlang,sym)
importFrom(rlang,syms)
importFrom(shiny,createRenderFunction)
importFrom(shiny,createWebDependency)
importFrom(shiny,exprToFunction)
importFrom(shiny,getDefaultReactiveDomain)
importFrom(shiny,registerInputHandler)
importFrom(shiny,shinyAppFile)
importFrom(shiny,uiOutput)
importFrom(stats,complete.cases)
importFrom(stats,lm)
importFrom(stats,loess)
importFrom(stats,predict)
importFrom(stats,setNames)
importFrom(utils,modifyList)
